@@ -1,9 +1,9 @@
 # encoding: binary
 #  Phusion Passenger - https://www.phusionpassenger.com/
-#  Copyright (c) 2010-2017 Phusion Holding B.V.
+#  Copyright (c) 2010-2025 Asynchronous B.V.
 #
 #  "Passenger", "Phusion Passenger" and "Union Station" are registered
-#  trademarks of Phusion Holding B.V.
+#  trademarks of Asynchronous B.V.
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to deal
@@ -633,9 +633,7 @@ module PhusionPassenger
           # files. On Hongli's and Camden's systems it's inside the Xcode directory,
           # while on https://github.com/phusion/passenger/issues/1986 it's inside
           # /Library/Developer/CommandLineTools.
-          xcode_prefix = `/usr/bin/xcode-select -p`.strip
-          flags << "-I#{xcode_prefix}/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk/usr/include/apache2"
-          flags << "-I/Library/Developer/CommandLineTools/SDKs/MacOSX.sdk/usr/include/apache2"
+          flags << "-I#{`xcrun --show-sdk-path`.strip}/usr/include/apache2"
         end
       else
         apxs2_flags = `#{apxs2} -q CFLAGS`.strip << " -I" << `#{apxs2} -q INCLUDEDIR`.strip
@@ -675,7 +673,7 @@ module PhusionPassenger
         # macOS >= 10.12 Sierra no longer includes apr-config
         # so we'll use a hardcoded path here.
         if os_name_simple == 'macosx' && os_version >= '10.12' && httpd == '/usr/sbin/httpd'
-          apxs2_flags << ' -I/usr/include/apr-1'
+          apxs2_flags << " -I#{`xcrun --show-sdk-path`.strip}/usr/include/apr-1"
         end
 
         apxs2_flags.strip!
@@ -689,11 +687,12 @@ module PhusionPassenger
         # Running 'file' on the Apache executable usually outputs something
         # like this:
         #
-        #   /usr/sbin/httpd: Mach-O universal binary with 4 architectures
+        #   /usr/sbin/httpd: Mach-O universal binary with 5 architectures
         #   /usr/sbin/httpd (for architecture ppc7400):     Mach-O executable ppc
         #   /usr/sbin/httpd (for architecture ppc64):       Mach-O 64-bit executable ppc64
         #   /usr/sbin/httpd (for architecture i386):        Mach-O executable i386
         #   /usr/sbin/httpd (for architecture x86_64):      Mach-O 64-bit executable x86_64
+        #   /usr/sbin/httpd (for architecture arm64e):	    Mach-O 64-bit executable arm64
         #
         # But on some machines, it may output just:
         #
@@ -702,12 +701,14 @@ module PhusionPassenger
         # (http://code.google.com/p/phusion-passenger/issues/detail?id=236)
         output = `file "#{httpd}"`.strip
         if output =~ /Mach-O fat file/ && output !~ /for architecture/
-          architectures = ["i386", "ppc", "x86_64", "ppc64"]
+          architectures = ["i386", "ppc", "x86_64", "ppc64", "arm64"]
         else
           architectures = []
           output.split("\n").grep(/for architecture/).each do |line|
             line =~ /for architecture (.*?)\)/
-            architectures << $1
+            arch = $1
+            arch = "arm64" if arch.start_with?("arm64")
+            architectures << arch
           end
         end
         # The compiler may not support all architectures in the binary.
@@ -728,7 +729,7 @@ module PhusionPassenger
     # Linker flags that are necessary for linking an Apache module.
     # Already includes APR and APU linker flags.
     def self.apache2_module_cxx_ldflags
-      flags = ""
+      flags = String.new
       if !apxs2.nil?
         flags << `#{apxs2} -q LDFLAGS`.strip
       end
@@ -839,9 +840,7 @@ module PhusionPassenger
             # files. On Hongli's and Camden's systems it's inside the Xcode directory,
             # while on https://github.com/phusion/passenger/issues/1986 it's inside
             # /Library/Developer/CommandLineTools.
-            xcode_prefix = `/usr/bin/xcode-select -p`.strip
-            ["-I#{xcode_prefix}/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk/usr/include/apr-1 " \
-             "-I#{xcode_prefix}/SDKs/MacOSX.sdk/usr/include/apr-1",
+            ["-I#{`xcrun --show-sdk-path`.strip}/usr/include/apr-1",
              '-lapr-1']
           else
             ['-I/usr/include/apr-1', '-lapr-1']
@@ -889,9 +888,7 @@ module PhusionPassenger
           if os_version >= '10.13'
             # On macOS >= 10.13 High Sierra /usr/include no longer
             # exists.
-            xcode_prefix = `/usr/bin/xcode-select -p`.strip
-            ["-I#{xcode_prefix}/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk/usr/include/apr-1 " \
-             "-I#{xcode_prefix}/SDKs/MacOSX.sdk/usr/include/apr-1",
+            ["-I#{`xcrun --show-sdk-path`.strip}/usr/include/apr-1",
              '-laprutil-1']
           else
             ['-I/usr/include/apr-1', '-laprutil-1']
@@ -1013,7 +1010,7 @@ module PhusionPassenger
 
     def self.unescape_c_string(s)
       state = 0
-      res = ''
+      res = String.new
       backslash = "\\"
       s.each_char do |c|
         case state
